@@ -203,7 +203,7 @@ is_our_board (GcomprisBoard *gcomprisBoard)
 {
   if (gcomprisBoard)
     {
-      if(g_strcasecmp(gcomprisBoard->type, "clockgame")==0)
+      if(g_ascii_strcasecmp(gcomprisBoard->type, "clockgame")==0)
 	{
 	  /* Set the plugin entry */
 	  gcomprisBoard->plugin=&menu_bp;
