@@ -251,7 +251,7 @@ static gboolean is_our_board (GcomprisBoard *gcomprisBoard) {
 
   if (gcomprisBoard) {
 
-      if (g_strcasecmp(gcomprisBoard->type, "crane") == 0) {
+      if (g_ascii_strcasecmp(gcomprisBoard->type, "crane") == 0) {
 
 	  /* Set the plugin entry */
 	  gcomprisBoard->plugin = &menu_bp;
