@@ -133,13 +133,13 @@ new_button(GooCanvasItem *rootitem,
   g_object_set_data (G_OBJECT(item), "flag",
 		     GUINT_TO_POINTER(flag));
   g_signal_connect (item, "enter_notify_event",
-		    (GtkSignalFunc) on_enter_notify,
+		    (GCallback) on_enter_notify,
                     GUINT_TO_POINTER(flag));
   g_signal_connect (item, "leave_notify_event",
-		    (GtkSignalFunc) on_leave_notify,
+		    (GCallback) on_leave_notify,
                     GUINT_TO_POINTER(flag));
   g_signal_connect(item, "button_press_event",
-		   (GtkSignalFunc) item_event_bar,
+		   (GCallback) item_event_bar,
 		   GUINT_TO_POINTER(flag));
   return item;
 }
@@ -438,6 +438,7 @@ bar_set (const GComprisBarFlags flags)
 static void
 bar_hide (gboolean hide)
 {
+  GcomprisProperties *properties = gc_prop_get();
   /* Non yet initialized : Something Wrong */
   if ( ! rootitem )
     return;
@@ -451,7 +452,8 @@ bar_hide (gboolean hide)
     }
   else
     {
-      g_object_set(rootitem,
+      if(!properties->bar_hidden)
+        g_object_set(rootitem,
 		   "visibility", GOO_CANVAS_ITEM_VISIBLE, NULL);
     }
 
@@ -508,6 +510,7 @@ static gchar *bar_flags_to_name(GComprisBarFlags flag)
       result = "quit";
       break;
     case GC_BAR_LEVEL_DOWN:
+      result = "level";
       break;
     case GC_BAR_HELP:
       result = "help";
@@ -528,11 +531,10 @@ static gint bar_play_sound (GooCanvasItem *item)
 
   GComprisBarFlags flag =
     GPOINTER_TO_UINT(g_object_get_data(G_OBJECT (item), "flag"));
+
   str = g_strdup_printf("voices/$LOCALE/misc/%s.ogg",
 			bar_flags_to_name(flag));
-
   gc_sound_play_ogg(str, NULL);
-
   g_free(str);
 
   gc_sound_policy_set(policy);
@@ -558,7 +560,7 @@ on_enter_notify (GooCanvasItem  *item,
     return FALSE;
 
   sound_play_id =
-    g_timeout_add (1000, (GtkFunction) bar_play_sound, item);
+    g_timeout_add (1000, (GSourceFunc) bar_play_sound, item);
 
   return FALSE;
 }
@@ -621,11 +623,12 @@ item_event_bar (GooCanvasItem  *item,
         if(gcomprisBoard && current_level > gcomprisBoard->maxlevel)
           current_level=1;
 
+        gc_bar_play_level_voice(current_level);
+
         /* Set the level */
         if(gcomprisBoard && gcomprisBoard->plugin->set_level != NULL)
           gcomprisBoard->plugin->set_level(current_level);
 
-        gc_bar_play_level_voice(current_level);
       }
       break;
     case GC_BAR_LEVEL_DOWN:
@@ -635,11 +638,12 @@ item_event_bar (GooCanvasItem  *item,
         if(current_level < 1)
           current_level = gcomprisBoard->maxlevel;
 
+        gc_bar_play_level_voice(current_level);
+
         /* Set the level */
         if(gcomprisBoard && gcomprisBoard->plugin->set_level != NULL)
           gcomprisBoard->plugin->set_level(current_level);
 
-        gc_bar_play_level_voice(current_level);
       }
       break;
     case GC_BAR_HOME:
