@@ -83,7 +83,7 @@ gc_bonus_display(GCBonusStatusList gamewon, GCBonusList bonus_id)
 	g_free(absolute_file);
       }
     else
-      gc_sound_play_ogg("sounds/tuxok.wav", NULL);
+      gc_sound_play_ogg("sounds/bonus.wav", NULL);
 
   } else {
     absolute_file = gc_file_find_absolute(loosingList[RAND(0, NUMBER_OF_LOOSING-1)]);
@@ -210,7 +210,7 @@ bonus_image(char *image, GCBonusStatusList gamewon)
   gdk_pixbuf_unref(pixmap);
 
   g_free(str);
-  end_bonus_id = g_timeout_add (GC_BONUS_DURATION, (GtkFunction) end_bonus, NULL);
+  end_bonus_id = g_timeout_add (GC_BONUS_DURATION, (GSourceFunc) end_bonus, NULL);
 }
 
 /* ==================================== */
