@@ -31,10 +31,6 @@
 
 #include "gcompris.h"
 
-#ifdef WIN32
-#define realpath(N,R) _fullpath((R),(N),_MAX_PATH)
-#endif
-
 extern GooCanvas *canvas;
 
 typedef void (*sighandler_t)(int);
@@ -331,15 +327,15 @@ void gc_item_focus_init(GooCanvasItem *source_item,
 
   /* Avoid double connection */
   g_signal_handlers_disconnect_by_func(source_item,
-				       (GtkSignalFunc) gc_item_focus_event,
+				       (GCallback) gc_item_focus_event,
 				       target_item);
 
   /* connect source to target */
   g_signal_connect(source_item, "enter_notify_event",
-		   (GtkSignalFunc) gc_item_focus_event,
+		   (GCallback) gc_item_focus_event,
 		   target_item);
   g_signal_connect(source_item, "leave_notify_event",
-		   (GtkSignalFunc) gc_item_focus_event,
+		   (GCallback) gc_item_focus_event,
 		   target_item);
 }
 
@@ -362,7 +358,7 @@ void gc_item_focus_remove(GooCanvasItem *source_item,
     target_item = source_item;
 
   g_signal_handlers_disconnect_by_func(source_item,
-				       (GtkSignalFunc) gc_item_focus_event,
+				       (GCallback) gc_item_focus_event,
 				       target_item);
 
   highlight_item = g_object_get_data (G_OBJECT(target_item),
@@ -561,7 +557,7 @@ gc_file_find_absolute(const gchar *format, ...)
   int			 i = 0;
   gchar			*filename;
   gchar			*absolute_filename;
-  gchar			*dir_to_search[4];
+  gchar			*dir_to_search[5];
   GcomprisProperties	*properties = gc_prop_get();
 
   if (!format)
@@ -649,6 +645,7 @@ gc_file_find_absolute(const gchar *format, ...)
     }
 
  NOT_FOUND:
+  g_debug("absolute_filename '%s' NOT FOUND\n", filename);
   g_free(filename);
   g_free(absolute_filename);
   return NULL;
@@ -656,8 +653,6 @@ gc_file_find_absolute(const gchar *format, ...)
  FOUND:
   g_free(filename);
   //  printf("absolute_filename=%s\n", absolute_filename);
-  //  char *abs_name = realpath(absolute_filename, NULL);
-  //g_free(absolute_filename);
   return absolute_filename;
 }
 
@@ -741,7 +736,7 @@ gc_util_button_text(GooCanvasItem *rootitem,
 		    guint x, guint y,
 		    char *button_file,
 		    char *text,
-		    GtkSignalFunc process,
+		    GCallback process,
 		    gpointer data)
 {
   GdkPixbuf *pixmap;
@@ -757,7 +752,7 @@ gc_util_button_text(GooCanvasItem *rootitem,
 			       NULL);
   g_signal_connect(item,
 		   "button_press_event",
-		   (GtkSignalFunc) process, data);
+		   (GCallback) process, data);
   gc_item_focus_init(item, NULL);
 
   /* The Text */
@@ -794,7 +789,7 @@ gc_util_button_text_svg(GooCanvasItem *rootitem,
 			guint x, guint y,
 			char *button_id,
 			char *text,
-			GtkSignalFunc process,
+			GCallback process,
 			gpointer data)
 {
   GooCanvasItem *item;
@@ -809,7 +804,7 @@ gc_util_button_text_svg(GooCanvasItem *rootitem,
 
   g_signal_connect(item,
 		   "button_press_event",
-		   (GtkSignalFunc) process, data);
+		   (GCallback) process, data);
   gc_item_focus_init(item, NULL);
 
   /* The Text */
