@@ -250,7 +250,7 @@ static gboolean is_our_board (GcomprisBoard *gcomprisBoard) {
 
   if (gcomprisBoard) {
 
-      if (g_strcasecmp(gcomprisBoard->type, "magic_hat") == 0) {
+      if (g_ascii_strcasecmp(gcomprisBoard->type, "magic_hat") == 0) {
 
 	  /* Set the plugin entry */
 	  gcomprisBoard->plugin = &menu_bp;
