@@ -215,7 +215,7 @@ is_our_board (GcomprisBoard *gcomprisBoard)
 {
   if (gcomprisBoard)
     {
-      if(g_strcasecmp(gcomprisBoard->type, "missingletter")==0)
+      if(g_ascii_strcasecmp(gcomprisBoard->type, "missingletter")==0)
 	{
 	  /* Set the plugin entry */
 	  gcomprisBoard->plugin=&menu_bp;
@@ -649,13 +649,13 @@ gboolean missing_read_xml_file(char *fname, GList **list)
      /* if it doesn't have a name */
      !doc->children->name ||
      /* if it isn't a missing letter node */
-     g_strcasecmp((char *)doc->children->name,"missing_letter")!=0) {
+     g_ascii_strcasecmp((char *)doc->children->name,"missing_letter")!=0) {
     xmlFreeDoc(doc);
     return FALSE;
   }
 
   for(node = doc->children->children; node != NULL; node = node->next) {
-    if ( g_strcasecmp((gchar *)node->name, "Board") == 0 )
+    if ( g_ascii_strcasecmp((gchar *)node->name, "Board") == 0 )
       add_xml_data(doc, node, list);
   }
   xmlFreeDoc(doc);
