@@ -234,7 +234,7 @@ gboolean is_our_board (GcomprisBoard *gcomprisBoard)
 {
   if (gcomprisBoard)
     {
-      if(g_strcasecmp(gcomprisBoard->type, "railroad")==0)
+      if(g_ascii_strcasecmp(gcomprisBoard->type, "railroad")==0)
 	{
 	  /* Set the plugin entry */
 	  gcomprisBoard->plugin=&menu_bp;
